```{include} ../README.md
:end-before: "## About"
```

```{include} ../README.md
:start-after: "## About"
:end-before: "## Installation"
```

```{toctree}
:numbered:
installation.md
usage.md
cliapi.md
changes.md
contributing.md
license.md
authors.md
```
